// Correct text resizing oddly when body font-size is set using em units
html { -ms-text-size-adjust: 100%; }

// Improve image quality when scaled 
img { -ms-interpolation-mode: bicubic; }

// Correct alignment displayed oddly
legend { *margin-left: -7px; }

// Correct inner spacing displayed oddly
button, input[type="button"], input[type="reset"], input[type="submit"] { *overflow: visible; }

button, input, select, textarea { *vertical-align: middle;}

audio, canvas, video { *display: inline; *zoom: 1; }

pre, code, kbd, samp { *font-family: 'courier new', monospace; font-size: 1em; }
