// Set vars as needed
$base         : #101010;
$base_alt     : lighten($base, 5%);
$base_alt2    : lighten($base, 15%);
$inverse      : #ddd;
$inverse_alt  : darken($inverse, 15%);
$accent_alt   : #d1b78b; // a goldy color for links and other places we don't want the orange.

@import '../site.scss';
@import '../layout_snippets/_horizontal_navigation.scss';

header[role=banner], 
footer[role=contentinfo] {
  background: #000;
  @include breakpoint(s) { background: #000 url('/static/img/site/6120-bg.jpg') no-repeat right; };

  &, header, a, .trigger, .navicon  {
    color: $inverse;
    &:hover {color: #fff}
  }
  nav a {
    text-shadow: 0 1px 1px rgba(0,0,0,.9), 0 0 20px #000, 0 0 10px #000, 0 0 5px #000;
  }
  .navicon:before { color: $inverse_alt }
}

footer[role=contentinfo] { background-position: bottom right; }
