#photoset_slides_hold, #photoset_slides_hold #photoset_slides { overflow: hidden; position: relative; }
#photoset_slides_hold figure { cursor: e-resize; float: left; position: relative; width: 100%; }
#photoset_slides_hold figure.vertical { text-align: center; }
#photoset_slides_hold figcaption { display: none; }
@media (min-width: 940px) { #photoset_slides_hold { max-width: 720px; }
  #photoset_slides_hold figure.vertical img { max-width: 540px; }
  #photoset_slides_hold body:after { content: "large"; } }

@media (min-width: 540px) { #photoset_info #caption_hold { font-size: 85%; }
  #photoset_info .next span, #photoset_info .prev span { display: none; }
  #photoset_info body:after { content: "small"; } }
