ul.fancy, ol.fancy {
  li {
    margin-bottom: $baseline; 
    padding-bottom: $baseline; 
    border-bottom: 1px solid $base
  }
}

ul.fancy {
  list-style:none; 
  padding-left: 0;
}

dl {
  @extend .sub-text;
  @extend .margin-bottom;

  &.specs {
    @extend .small-text;
    max-width: 300px; 
  }

  dt {
    float:left; 
    display:block; 
    font-weight:bold; 
    clear:left; 
    margin:0; 
    padding: $baseline 0 0;
    color: $meta;
    border-top:1px dotted $base_alt2; 
    width: 30%;
  }
  dd { 
    padding: $baseline $gutter $defaultMargin; 
    margin-left: 30%;
    min-height:2em; 
    border-left: 1px solid $base_alt2;
  } 
  dt+dd { border-top:1px dotted $base_alt2; }
}

section.list { // often used in conjunction with a grid (column) view in tabs
  > ul {list-style:none; margin:0; }
  > div, > ul > li {
    display: table;
    width: 100%;
    
    > * {
      @extend .pad-top-bottom;
      display: table-cell; 
      border-bottom: 1px solid $base_alt2; 
      min-height:60px;
    }

    .third {width:33%;
      .url-selector {width:100%;}
    }
  }
  ul, dl {
    figure {width:50px; max-height:50px; overflow:hidden}
    dt, dd {
      @extend .sub-text;
      min-height:60px;
    }
  }
}
