/********************************************* Capo typography is defined by a handful of variables which create a 10 px baseline grid and size various typographic elements appropriately to remain on that grid.
 This file also defines variables that can be used for consistent margins, padding and gutters:
 - @gutter: for columns between content. 20px - @halfGutter: for padding in boxes, etc. Half of gutter. - @defaultMargin: For consistently setting top and bottom margins while staying on the baseline grid. Note: you can use multiples ( @defaultMargin * 2 );
**********************************************/
html, button, input, select, textarea { font-family: "Helvetica", "Calibri", "Lucida Sans Unicode", "Arial Unicode MS", Verdana, Arial, sans-serif; }

button, input, select, textarea { font-size: 100%; }

html { font-size: 1em; -webkit-text-size-adjust: 100%; -ms-text-size-adjust: 100%; }

.small-text, sub, sup, small { font-size: 12px; line-height: 18px; font-size: 0.75rem; line-height: 1.125rem; }

.sub-text, [role=complementary] { font-size: 12px; line-height: 18px; font-size: 0.75rem; line-height: 1.125rem; }
@media (min-width: 760px) { .sub-text, [role=complementary] { font-size: 14px; font-size: 0.875rem; line-height: 18px; line-height: 1.125rem; }
  .sub-text body:after, [role=complementary] body:after { content: "medium"; } }

.body-text, body { font-size: 14px; font-size: 0.875rem; line-height: 18px; line-height: 1.125rem; }
@media (min-width: 760px) { .body-text, body { font-size: 16px; font-size: 1em; line-height: 24px; line-height: 1.5rem; }
  .body-text body:after, body body:after { content: "medium"; } }

.x-small-header, h5, .breakout-text { font-size: 16px; font-size: 1em; line-height: 24px; line-height: 1.5rem; }
@media (min-width: 760px) { .x-small-header, h5, .breakout-text { font-size: 16px; font-size: 1.142857rem; line-height: 24px; line-height: 1.33rem; }
  .x-small-header body:after, h5 body:after, .breakout-text body:after { content: "medium"; } }

.small-header, .hero, .kicker, [role=complementary] h3, h4 { font-size: 16px; font-size: 1.142857rem; line-height: 24px; line-height: 1.33rem; }
@media (min-width: 760px) { .small-header, .hero, .kicker, [role=complementary] h3, h4 { font-size: 18px; font-size: 1.125rem; line-height: 24px; line-height: 1.25rem; }
  .small-header body:after, .hero body:after, .kicker body:after, [role=complementary] h3 body:after, h4 body:after { content: "medium"; } }

.medium-header, [role=complementary] h2, h3, .subhead { font-size: 18px; font-size: 1.125rem; line-height: 24px; line-height: 1.25rem; }
@media (min-width: 760px) { .medium-header, [role=complementary] h2, h3, .subhead { font-size: 21px; font-size: 1.2857rem; line-height: 24px; line-height: 1.5rem; }
  .medium-header body:after, [role=complementary] h2 body:after, h3 body:after, .subhead body:after { content: "medium"; } }

.large-header, [role=complementary] h1, h2 { font-size: 21px; font-size: 1.2857rem; line-height: 24px; line-height: 1.5rem; }
@media (min-width: 760px) { .large-header, [role=complementary] h1, h2 { font-size: 30px; font-size: 1.875rem; line-height: 36px; line-height: 2.25rem; }
  .large-header body:after, [role=complementary] h1 body:after, h2 body:after { content: "medium"; } }

.xl-header, h1 { font-size: 30px; font-size: 1.875rem; line-height: 36px; line-height: 2.25rem; }
@media (min-width: 760px) { .xl-header, h1 { font-size: 36px; line-height: 48px; font-size: 2.25rem; line-height: 3rem; }
  .xl-header body:after, h1 body:after { content: "medium"; } }

[role=banner] h1 { font-size: 42px; font-size: 3rem; }

.super-text, .hero h1 { font-size: 36px; line-height: 48px; font-size: 2.25rem; line-height: 3rem; }
@media (min-width: 760px) { .super-text, .hero h1 { font-size: 48px; line-height: 60px; font-size: 3.42857rem; line-height: 4.2857rem; }
  .super-text body:after, .hero h1 body:after { content: "medium"; } }

/*
h1, h2, h3, h4 { font-family: 'OpenSansSemibold'; }



.bold-text { font-family: 'OpenSansSemiBold'; }
.unbold-text { font-family: 'OpenSansRegular'; }
.light-text { font-family: 'OpenSansLight'; }

b, strong { .bold-text;
}

p + p,
p + div,
p + h2,
p + h3 { margin-top: @defaultMargin;
}
p + p.small-text { margin: 0.875em 0 0.25em;
}
.sidebar-wrapper { font-size: .9em;}

*/
pre, code, kbd, samp { font-family: monospace, serif; _font-family: 'courier new', monospace; font-size: 1em; }

sub, sup { line-height: 0; position: relative; vertical-align: baseline; }

sup { top: -0.5em; }

sub { bottom: -0.25em; }

h1, h2, h3, h4, h5, h6, p, ol, ul { margin: 0; }

h1, h2, h3, h4, h5, h6 { font-weight: bold; }

#content-wrapper p, #content-wrapper ol, #content-wrapper ul, #content-wrapper small { margin: 12px 0; }
#content-wrapper p + h2, #content-wrapper p + h3 { padding-top: 24px; }
#content-wrapper h3 + p { margin-top: 0; }

.meta { color: #888888; }

.kicker { text-transform: uppercase; }

small { display: inline-block; }

#mapholder { height: 240px; width: 320px; margin-right: 20px; }
#mapholder #map_canvas { height: 240px; }
